@@ -20,50 +20,47 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Compare the request file and the confirmation file.
-"""
+"""Compare the request file and the confirmation file."""
 
+import glob
 import logging
 import logging.handlers
-import sys
 import os
-import glob
 
 logger = logging.getLogger(__name__)
 
 
 def xml_compare(x1_, x2_, reporter=None, skiptags=None):
-    """Compare xml objects.
-    """
+    """Compare xml objects."""
     if x1_.tag != x2_.tag:
         if reporter:
-            reporter('Tags do not match: %s and %s' % (x1_.tag, x2_.tag))
+            reporter("Tags do not match: %s and %s" % (x1_.tag, x2_.tag))
         return False
     for name, value in x1_.attrib.items():
         if x2_.attrib.get(name) != value:
             if reporter:
-                reporter('Attributes do not match: %s=%r, %s=%r'
+                reporter("Attributes do not match: %s=%r, %s=%r"
                          % (name, value, name, x2_.attrib.get(name)))
             return False
     for name in x2_.attrib.keys():
         if name not in x1_.attrib:
             if reporter:
-                reporter('x2_ has an attribute x1_ is missing: %s'
+                reporter("x2_ has an attribute x1_ is missing: %s"
                          % name)
             return False
     if not text_compare(x1_.text, x2_.text):
         if reporter:
-            reporter('text: %r != %r' % (x1_.text, x2_.text))
+            reporter("text: %r != %r" % (x1_.text, x2_.text))
         return False
     if not text_compare(x1_.tail, x2_.tail):
         if reporter:
-            reporter('tail: %r != %r' % (x1_.tail, x2_.tail))
+            reporter("tail: %r != %r" % (x1_.tail, x2_.tail))
         return False
     cl1 = x1_.getchildren()
     cl2 = x2_.getchildren()
     if len(cl1) != len(cl2):
         if reporter:
-            reporter('not the same number of passes, %i != %i'
+            reporter("not the same number of passes, %i != %i"
                      % (len(cl1), len(cl2)))
         return False
     i = 0
@@ -73,26 +70,24 @@ def xml_compare(x1_, x2_, reporter=None, skiptags=None):
             continue
         if not xml_compare(c1, c2, reporter=reporter):
             if reporter:
-                reporter('element %i do not match: %s'
+                reporter("element %i do not match: %s"
                          % (i, c1.tag))
             return False
     return True
 
 
 def text_compare(t1_, t2_):
-    """Compare text fields.
-    """
+    """Compare text fields."""
     if not t1_ and not t2_:
         return True
-    if t1_ == '*' or t2_ == '*':
+    if t1_ == "*" or t2_ == "*":
         return True
-    return (t1_ or '').strip() == (t2_ or '').strip()
+    return (t1_ or "").strip() == (t2_ or "").strip()
 
 
 def compare(file1, file2):
-    """Compare two xml files, request and confirmation.
-    """
-    import xml.etree.ElementTree as ET
+    """Compare two xml files, request and confirmation."""
+    import defusedxml.ElementTree as ET
     xml1 = ET.parse(file1).getroot()
     xml2 = ET.parse(file2).getroot()
     if xml_compare(xml1, xml2, logger.error,
@@ -122,6 +117,7 @@ def compare(file1, file2):
 #         self.process_IN_CLOSE_WRITE(event)
 
 def run():
+    """Run the comparison."""
     import argparse
 
     parser = argparse.ArgumentParser()
@@ -152,15 +148,15 @@ def run():
         handler = logging.StreamHandler()
     handler.setFormatter(logging.Formatter("[%(levelname)s: %(asctime)s :"
                                            " %(name)s] %(message)s",
-                                           '%Y-%m-%d %H:%M:%S'))
+                                           "%Y-%m-%d %H:%M:%S"))
 
     if opts.verbose:
         loglevel = logging.DEBUG
     else:
         loglevel = logging.INFO
     handler.setLevel(loglevel)
-    logging.getLogger('').setLevel(loglevel)
-    logging.getLogger('').addHandler(handler)
+    logging.getLogger("").setLevel(loglevel)
+    logging.getLogger("").addHandler(handler)
 
     if opts.mail:
         mhandler = logging.handlers.SMTPHandler("localhost",
@@ -168,7 +164,7 @@ def run():
                                                 opts.mail,
                                                 "Scheduler confirmation")
         mhandler.setLevel(logging.WARNING)
-        logging.getLogger('').addHandler(mhandler)
+        logging.getLogger("").addHandler(mhandler)
     logger = logging.getLogger("compare")
 
     logger.debug("DEBUG on")
@@ -202,5 +198,5 @@ def run():
             logger.exception("Something went wrong!")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     run()
