@@ -45,7 +45,7 @@ class TestTools:
                 self.risetime = rise
                 self.falltime = fall
 
-        ref_time = datetime.utcnow()
+        ref_time = datetime(2020, 1, 1, 18, 0)
         passes = [MyPass(ref_time, ref_time + timedelta(minutes=10)),
                   MyPass(ref_time + timedelta(minutes=10.01),
                          ref_time + timedelta(minutes=20))]
@@ -314,6 +314,39 @@ class TestAll:
             assert (metopa_passes[0].uptime - datetime(2018, 12, 4, 9, 17, 48, 530484)).seconds == 0
             assert (metopa_passes[0].risetime - datetime(2018, 12, 4, 9, 17, 21, 644605)).seconds == 0
 
+    def test_write_metno_xml(self, tmp_path):
+        """Test that writing pass list in metno xml format work as expected."""
+        from datetime import timezone
+        from trollsched.writers import generate_metno_xml_file
+        import defusedxml.ElementTree as ET
+
+        with open(tmp_path / "tle.file", "wt") as f:
+            f.write(self.satellites[0].upper() + "\n")
+            f.write(self.tles[self.satellites[0]]['line1'] + "\n")
+            f.write(self.tles[self.satellites[0]]['line2'] + "\n")
+            f.close()
+
+            allpasses = get_next_passes(self.satellites, self.utctime,
+                                        4, (16, 58, 0), tle_file=str(tmp_path / "tle.file"))
+            coords = (10, 60, 0.1)
+            written_test_file = generate_metno_xml_file(tmp_path / "test.xml", allpasses,
+                                                        coords, self.utctime,
+                                                        self.utctime + timedelta(hours=5), "id", "center_id",
+                                                        report_mode=True)
+            # Read back to test content
+            tree = ET.parse(written_test_file)
+            root = tree.getroot()
+            assert root.find('properties/project').text == 'Pytroll'
+            assert root.find('properties/type').text == 'report'
+            assert root.find('properties/station').text == 'id'
+            assert root.find('properties/requested-by').text == 'center_id'
+            assert root.find('properties/file-start').text == '2018-11-28T10:00:00'
+            assert root.find('properties/file-end').text == '2018-11-28T15:00:00'
+            expected_aos = ['20181128105342', '20181128123444']
+            expected_los = ['20181128110906', '20181128124925']
+            for overpass, exp_aos, exp_los in zip(root.iter("pass"), expected_aos, expected_los):
+                assert overpass.attrib["aos"] == exp_aos
+                assert overpass.attrib["los"] == exp_los
 
 euron1 = """euron1:
   description: Northern Europe - 1km
@@ -372,7 +405,7 @@ def test_pyorbitals_platform_name(tmp_path):
     with open(config_file, "w") as fd:
         fd.write(yaml.dump(config))
 
-    run(["-c", os.fspath(config_file), "-x", "-t", os.fspath(tle_file)])
+    run(["-c", os.fspath(config_file), "-x", "-t", os.fspath(tle_file), "-s", "2024-03-30T15:00"])
     assert sched_file in tmp_path.iterdir()
 
 
@@ -436,10 +469,12 @@ def test_schedule_avoid(tmp_path):
 
     start_time = datetime(2024, 5, 8, 0, 0, 0)
     run(["-c", os.fspath(config_file), "-x", "-v", "-t", os.fspath(tle_file),
-         "--start-time", start_time.strftime("%Y-%m-%dT%H:%M:%S"), "--avoid", os.fspath(avoid_file)])
+         "--start-time", start_time.strftime("%Y-%m-%dT%H:%M:%S"),
+         "--avoid", os.fspath(avoid_file)])
     assert sched_file in tmp_path.iterdir()
 
     sched_file_passes = get_passes_from_xml_file([sched_file])
     avoid_file_passes = get_passes_from_xml_file([avoid_file])
     for avoid_pass in avoid_file_passes:
         assert avoid_pass not in sched_file_passes
+
